==> console-0.2.0.jar: clj_eden/console/core.clj <==
(ns clj-eden.console.core
  (:require [clj-eden.colls.core :refer [in?]]
            [clojure.string :as string]))

(defn prompt
  "Give a prompt and return non-empty user input optionally with a default message"
  ([msg]
    (print (str msg " "))
    (flush)
    (def response (read-line))
    (if (empty? response)
      (prompt msg)
      response))
  ([msg default]
    (print (str msg " [" default "] "))
    (flush)
    (def response (read-line))
    (if (empty? response)
      default
      response)))

(defn prompt-options [msg options]
  "Prompt for and return user input reprompting until one of a set of option strings is choosen"
  (loop []
    (print (str msg " [" (string/join "," options) "] "))
    (flush)
    (def response (read-line))
    (if (in? options response)
      response
      (recur))))

(defn prompt-pw [msg]
  "Prompt for and return a password not echoing"
  (print (str msg " ")) (flush)
  (apply str (.readPassword (System/console))))

(defn prompt-yn [msg]
  "Prompt for an affirmative or negative response returning true or false"
  (defn affirmative [response]
    (in? ["y" "yes" "yep" "sure" "ok" "agreed" "make it so" "yea" "yeah" "no problem" "affirmative"] (.toLowerCase response)))
  (defn negative [response]
    (in? ["n" "no" "nope" "no way" "negative" "nay" "not a chance" "you wish"] (.toLowerCase response)))
  (loop []
    (print (str msg " "))
    (flush)
    (def response (read-line))
    (if (or (affirmative response) (negative response))
      (affirmative response)
      (recur))))

==> console-0.2.2.jar: clj_eden/console/core.clj <==
(ns clj-eden.console.core
  (:require [clj-eden.colls.core :refer [in?]]
            [clojure.string :as string]))

(defn prompt
  "Give a prompt and return non-empty user input optionally with a default message"
  ([msg]
    (print (str msg " "))
    (flush)
    (def response (read-line))
    (if (empty? response)
      (prompt msg)
      response))
  ([msg default]
    (print (str msg " [" default "] "))
    (flush)
    (def response (read-line))
    (if (empty? response)
      default
      response)))

(defn prompt-options [msg options]
  "Prompt for and return user input reprompting until one of a set of option strings is choosen"
  (loop []
    (print (str msg " [" (string/join "," options) "] "))
    (flush)
    (def response (read-line))
    (if (in? options response)
      response
      (recur))))

(defn prompt-pw [msg]
  "Prompt for and return a password not echoing"
  (print (str msg " ")) (flush)
  (apply str (.readPassword (System/console))))

(defn prompt-yn [msg]
  "Prompt for an affirmative or negative response returning true or false"
  (defn affirmative [response]
    (in? ["y" "yes" "yep" "sure" "ok" "agreed" "make it so" "yea" "yeah" "no problem" "affirmative"] (.toLowerCase response)))
  (defn negative [response]
    (in? ["n" "no" "nope" "no way" "negative" "nay" "not a chance" "you wish"] (.toLowerCase response)))
  (loop []
    (print (str msg " "))
    (flush)
    (def response (read-line))
    (if (or (affirmative response) (negative response))
      (affirmative response)
      (recur))))

(defn percent-bar [percent]
  (let [slen (int (/ percent 2))
        shaft (apply str (repeat slen "="))
        filler (apply str (repeat (- 50 slen) " "))]
    (println "") ; will be removed by the following line
    (printf "\033[F\033[J")
    (str "[" shaft ">" filler "] " percent "%")))
